
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import resource_handle_pb2 as tensorflow_dot_core_dot_framework_dot_resource__handle__pb2
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/tensor.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x0cTensorProtosP\x01ZMgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/tensor_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n&tensorflow/core/framework/tensor.proto\x12\ntensorflow\x1a/tensorflow/core/framework/resource_handle.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto"\x8c\x04\n\x0bTensorProto\x12#\n\x05dtype\x18\x01 \x01(\x0e2\x14.tensorflow.DataType\x122\n\x0ctensor_shape\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto\x12\x16\n\x0eversion_number\x18\x03 \x01(\x05\x12\x16\n\x0etensor_content\x18\x04 \x01(\x0c\x12\x14\n\x08half_val\x18\r \x03(\x05B\x02\x10\x01\x12\x15\n\tfloat_val\x18\x05 \x03(\x02B\x02\x10\x01\x12\x16\n\ndouble_val\x18\x06 \x03(\x01B\x02\x10\x01\x12\x13\n\x07int_val\x18\x07 \x03(\x05B\x02\x10\x01\x12\x12\n\nstring_val\x18\x08 \x03(\x0c\x12\x18\n\x0cscomplex_val\x18\t \x03(\x02B\x02\x10\x01\x12\x15\n\tint64_val\x18\n \x03(\x03B\x02\x10\x01\x12\x14\n\x08bool_val\x18\x0b \x03(\x08B\x02\x10\x01\x12\x18\n\x0cdcomplex_val\x18\x0c \x03(\x01B\x02\x10\x01\x12<\n\x13resource_handle_val\x18\x0e \x03(\x0b2\x1f.tensorflow.ResourceHandleProto\x127\n\x0bvariant_val\x18\x0f \x03(\x0b2".tensorflow.VariantTensorDataProto\x12\x16\n\nuint32_val\x18\x10 \x03(\rB\x02\x10\x01\x12\x16\n\nuint64_val\x18\x11 \x03(\x04B\x02\x10\x01"g\n\x16VariantTensorDataProto\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\x0c\x12(\n\x07tensors\x18\x03 \x03(\x0b2\x17.tensorflow.TensorProtoB|\n\x18org.tensorflow.frameworkB\x0cTensorProtosP\x01ZMgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/tensor_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_resource__handle__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_TENSORPROTO = _descriptor.Descriptor(name='TensorProto', full_name='tensorflow.TensorProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.TensorProto.dtype', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_shape', full_name='tensorflow.TensorProto.tensor_shape', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='version_number', full_name='tensorflow.TensorProto.version_number', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_content', full_name='tensorflow.TensorProto.tensor_content', index=3, number=4, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='half_val', full_name='tensorflow.TensorProto.half_val', index=4, number=13, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='float_val', full_name='tensorflow.TensorProto.float_val', index=5, number=5, type=2, cpp_type=6, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='double_val', full_name='tensorflow.TensorProto.double_val', index=6, number=6, type=1, cpp_type=5, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='int_val', full_name='tensorflow.TensorProto.int_val', index=7, number=7, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='string_val', full_name='tensorflow.TensorProto.string_val', index=8, number=8, type=12, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='scomplex_val', full_name='tensorflow.TensorProto.scomplex_val', index=9, number=9, type=2, cpp_type=6, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='int64_val', full_name='tensorflow.TensorProto.int64_val', index=10, number=10, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bool_val', full_name='tensorflow.TensorProto.bool_val', index=11, number=11, type=8, cpp_type=7, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dcomplex_val', full_name='tensorflow.TensorProto.dcomplex_val', index=12, number=12, type=1, cpp_type=5, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='resource_handle_val', full_name='tensorflow.TensorProto.resource_handle_val', index=13, number=14, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='variant_val', full_name='tensorflow.TensorProto.variant_val', index=14, number=15, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='uint32_val', full_name='tensorflow.TensorProto.uint32_val', index=15, number=16, type=13, cpp_type=3, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='uint64_val', full_name='tensorflow.TensorProto.uint64_val', index=16, number=17, type=4, cpp_type=4, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=189, serialized_end=713)
_VARIANTTENSORDATAPROTO = _descriptor.Descriptor(name='VariantTensorDataProto', full_name='tensorflow.VariantTensorDataProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='type_name', full_name='tensorflow.VariantTensorDataProto.type_name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.VariantTensorDataProto.metadata', index=1, number=2, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensors', full_name='tensorflow.VariantTensorDataProto.tensors', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=715, serialized_end=818)
_TENSORPROTO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_TENSORPROTO.fields_by_name['tensor_shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_TENSORPROTO.fields_by_name['resource_handle_val'].message_type = tensorflow_dot_core_dot_framework_dot_resource__handle__pb2._RESOURCEHANDLEPROTO
_TENSORPROTO.fields_by_name['variant_val'].message_type = _VARIANTTENSORDATAPROTO
_VARIANTTENSORDATAPROTO.fields_by_name['tensors'].message_type = _TENSORPROTO
DESCRIPTOR.message_types_by_name['TensorProto'] = _TENSORPROTO
DESCRIPTOR.message_types_by_name['VariantTensorDataProto'] = _VARIANTTENSORDATAPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TensorProto = _reflection.GeneratedProtocolMessageType('TensorProto', (_message.Message,), {'DESCRIPTOR': _TENSORPROTO, '__module__': 'tensorflow.core.framework.tensor_pb2'})
_sym_db.RegisterMessage(TensorProto)
VariantTensorDataProto = _reflection.GeneratedProtocolMessageType('VariantTensorDataProto', (_message.Message,), {'DESCRIPTOR': _VARIANTTENSORDATAPROTO, '__module__': 'tensorflow.core.framework.tensor_pb2'})
_sym_db.RegisterMessage(VariantTensorDataProto)
DESCRIPTOR._options = None
_TENSORPROTO.fields_by_name['half_val']._options = None
_TENSORPROTO.fields_by_name['float_val']._options = None
_TENSORPROTO.fields_by_name['double_val']._options = None
_TENSORPROTO.fields_by_name['int_val']._options = None
_TENSORPROTO.fields_by_name['scomplex_val']._options = None
_TENSORPROTO.fields_by_name['int64_val']._options = None
_TENSORPROTO.fields_by_name['bool_val']._options = None
_TENSORPROTO.fields_by_name['dcomplex_val']._options = None
_TENSORPROTO.fields_by_name['uint32_val']._options = None
_TENSORPROTO.fields_by_name['uint64_val']._options = None



import struct
import numpy as np
from . import strings

# namespace tensorflow {
# namespace core {

# void EncodeFixed16(char* buf, uint16 value) {
#   if (port::kLittleEndian) {
#     memcpy(buf, &value, sizeof(value));
#   } else {
#     buf[0] = value & 0xff;
#     buf[1] = (value >> 8) & 0xff;
#   }
# }
def encode_fixed16(value):
  value = int(np.uint16(value))
  return struct.pack("=H", value)

# void EncodeFixed32(char* buf, uint32 value) {
#   if (port::kLittleEndian) {
#     memcpy(buf, &value, sizeof(value));
#   } else {
#     buf[0] = value & 0xff;
#     buf[1] = (value >> 8) & 0xff;
#     buf[2] = (value >> 16) & 0xff;
#     buf[3] = (value >> 24) & 0xff;
#   }
# }
def encode_fixed32(value):
  value = int(np.uint32(value))
  return struct.pack("=L", value)

# void EncodeFixed64(char* buf, uint64 value) {
#   if (port::kLittleEndian) {
#     memcpy(buf, &value, sizeof(value));
#   } else {
#     buf[0] = value & 0xff;
#     buf[1] = (value >> 8) & 0xff;
#     buf[2] = (value >> 16) & 0xff;
#     buf[3] = (value >> 24) & 0xff;
#     buf[4] = (value >> 32) & 0xff;
#     buf[5] = (value >> 40) & 0xff;
#     buf[6] = (value >> 48) & 0xff;
#     buf[7] = (value >> 56) & 0xff;
#   }
# }
def encode_fixed64(value):
  value = int(np.uint64(value))
  return struct.pack("=Q", value)

# void PutFixed16(string* dst, uint16 value) {
#   char buf[sizeof(value)];
#   EncodeFixed16(buf, value);
#   dst->append(buf, sizeof(buf));
# }
def put_fixed16(dst: bytearray, value):
  buf = encode_fixed16(value)
  dst.extend(buf)

# void PutFixed32(string* dst, uint32 value) {
#   char buf[sizeof(value)];
#   EncodeFixed32(buf, value);
#   dst->append(buf, sizeof(buf));
# }
def put_fixed32(dst: bytearray, value):
  buf = encode_fixed32(value)
  dst.extend(buf)

# void PutFixed64(string* dst, uint64 value) {
#   char buf[sizeof(value)];
#   EncodeFixed64(buf, value);
#   dst->append(buf, sizeof(buf));
# }
def put_fixed64(dst: bytearray, value):
  buf = encode_fixed64(value)
  dst.extend(buf)

# char* EncodeVarint32(char* dst, uint32 v) {
#   // Operate on characters as unsigneds
#   unsigned char* ptr = reinterpret_cast<unsigned char*>(dst);
#   static const int B = 128;
#   if (v < (1 << 7)) {
#     *(ptr++) = v;
#   } else if (v < (1 << 14)) {
#     *(ptr++) = v | B;
#     *(ptr++) = v >> 7;
#   } else if (v < (1 << 21)) {
#     *(ptr++) = v | B;
#     *(ptr++) = (v >> 7) | B;
#     *(ptr++) = v >> 14;
#   } else if (v < (1 << 28)) {
#     *(ptr++) = v | B;
#     *(ptr++) = (v >> 7) | B;
#     *(ptr++) = (v >> 14) | B;
#     *(ptr++) = v >> 21;
#   } else {
#     *(ptr++) = v | B;
#     *(ptr++) = (v >> 7) | B;
#     *(ptr++) = (v >> 14) | B;
#     *(ptr++) = (v >> 21) | B;
#     *(ptr++) = v >> 28;
#   }
#   return reinterpret_cast<char*>(ptr);
# }
def encode_varint32(v):
  v = int(np.uint32(v))
  ptr = bytearray()
  def add(i):
    ptr.append(int(i) & 0xFF)
  B = 128
  # if (v < (1 << 7)) {
  #   *(ptr++) = v;
  if v < (1 << 7):
    ptr.append(v)
  # } else if (v < (1 << 14)) {
  #   *(ptr++) = v | B;
  #   *(ptr++) = v >> 7;
  elif v < (1 << 14):
    add(v | B)
    add(v >> 7)
  # } else if (v < (1 << 21)) {
  #   *(ptr++) = v | B;
  #   *(ptr++) = (v >> 7) | B;
  #   *(ptr++) = v >> 14;
  elif v < (1 << 21):
    add(v | B)
    add((v >> 7) | B)
    add(v >> 14)
  # } else if (v < (1 << 28)) {
  #   *(ptr++) = v | B;
  #   *(ptr++) = (v >> 7) | B;
  #   *(ptr++) = (v >> 14) | B;
  #   *(ptr++) = v >> 21;
  elif v < (1 << 28):
    add(v | B)
    add((v >> 7) | B)
    add((v >> 14) | B)
    add(v >> 21)
  # } else {
  #   *(ptr++) = v | B;
  #   *(ptr++) = (v >> 7) | B;
  #   *(ptr++) = (v >> 14) | B;
  #   *(ptr++) = (v >> 21) | B;
  #   *(ptr++) = v >> 28;
  # }
  else:
    add(v | B)
    add((v >> 7) | B)
    add((v >> 14) | B)
    add((v >> 21) | B)
    add(v >> 28)
  return ptr

# void PutVarint32(string* dst, uint32 v) {
#   char buf[5];
#   char* ptr = EncodeVarint32(buf, v);
#   dst->append(buf, ptr - buf);
# }
def put_varint32(dst: bytearray, v):
  buf = encode_varint32(v)
  dst.extend(buf)

# char* EncodeVarint64(char* dst, uint64 v) {
#   static const int B = 128;
#   unsigned char* ptr = reinterpret_cast<unsigned char*>(dst);
#   while (v >= B) {
#     *(ptr++) = (v & (B - 1)) | B;
#     v >>= 7;
#   }
#   *(ptr++) = static_cast<unsigned char>(v);
#   return reinterpret_cast<char*>(ptr);
# }
def encode_varint64(v):
  v = int(np.uint64(v))
  B = 128
  ptr = bytearray()
  def add(i):
    ptr.append(int(i) & 0xFF)
  while v >= B:
    add((v & (B - 1)) | B)
    v >>= 7
  add(v)
  return ptr

# void PutVarint64(string* dst, uint64 v) {
#   char buf[10];
#   char* ptr = EncodeVarint64(buf, v);
#   dst->append(buf, ptr - buf);
# }
def put_varint64(dst: bytearray, v):
  buf = encode_varint64(v)
  dst.extend(buf)

# void PutVarint64(tstring* dst, uint64 v) {
#   char buf[10];
#   char* ptr = EncodeVarint64(buf, v);
#   dst->append(buf, ptr - buf);
# }

# int VarintLength(uint64_t v) {
#   int len = 1;
#   while (v >= 128) {
#     v >>= 7;
#     len++;
#   }
#   return len;
# }
def varint_length(v):
  v = int(np.uint64(v))
  length = 1
  while v >= 128:
    v >>= 7
    length += 1
  return length

# const char* GetVarint32Ptr(const char* p, const char* limit, uint32* value) {
#   if (p < limit) {
#     uint32 result = *(reinterpret_cast<const unsigned char*>(p));
#     if ((result & 128) == 0) {
#       *value = result;
#       return p + 1;
#     }
#   }
#   return GetVarint32PtrFallback(p, limit, value);
# }
#
# const char* GetVarint32PtrFallback(const char* p, const char* limit,
#                                    uint32* value) {
#   uint32 result = 0;
#   for (uint32 shift = 0; shift <= 28 && p < limit; shift += 7) {
#     uint32 byte = *(reinterpret_cast<const unsigned char*>(p));
#     p++;
#     if (byte & 128) {
#       // More bytes are present
#       result |= ((byte & 127) << shift);
#     } else {
#       result |= (byte << shift);
#       *value = result;
#       return reinterpret_cast<const char*>(p);
#     }
#   }
#   return nullptr;
# }
#
# bool GetVarint32(StringPiece* input, uint32* value) {
#   const char* p = input->data();
#   const char* limit = p + input->size();
#   const char* q = GetVarint32Ptr(p, limit, value);
#   if (q == nullptr) {
#     return false;
#   } else {
#     *input = StringPiece(q, limit - q);
#     return true;
#   }
# }
#
# const char* GetVarint64Ptr(const char* p, const char* limit, uint64* value) {
#   uint64 result = 0;
#   for (uint32 shift = 0; shift <= 63 && p < limit; shift += 7) {
#     uint64 byte = *(reinterpret_cast<const unsigned char*>(p));
#     p++;
#     if (byte & 128) {
#       // More bytes are present
#       result |= ((byte & 127) << shift);
#     } else {
#       result |= (byte << shift);
#       *value = result;
#       return reinterpret_cast<const char*>(p);
#     }
#   }
#   return nullptr;
# }
#
# bool GetVarint64(StringPiece* input, uint64* value) {
#   const char* p = input->data();
#   const char* limit = p + input->size();
#   const char* q = GetVarint64Ptr(p, limit, value);
#   if (q == nullptr) {
#     return false;
#   } else {
#     *input = StringPiece(q, limit - q);
#     return true;
#   }
# }
#
# }  // namespace core
# }  // namespace tensorflow



'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from .....tensorflow.core.profiler.protobuf import op_metrics_pb2 as tensorflow_dot_core_dot_profiler_dot_protobuf_dot_op__metrics__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/steps_db.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n0tensorflow/core/profiler/protobuf/steps_db.proto\x12\x13tensorflow.profiler\x1a\x19google/protobuf/any.proto\x1a2tensorflow/core/profiler/protobuf/op_metrics.proto"\x8d\x01\n\x14GenericStepBreakdown\x12F\n\x07type_ps\x18\x01 \x03(\x0b25.tensorflow.profiler.GenericStepBreakdown.TypePsEntry\x1a-\n\x0bTypePsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x04:\x028\x01"V\n\x14DeviceMemoryTransfer\x12\x12\n\noccurrence\x18\x01 \x01(\x04\x12\x0f\n\x07time_us\x18\x02 \x01(\x01\x12\x19\n\x11bytes_transferred\x18\x03 \x01(\x04"\x8a\x01\n\x0eStepInfoResult\x12\x10\n\x08step_num\x18\x01 \x01(\r\x12\x11\n\tstep_name\x18\x05 \x01(\t\x12\x13\n\x0bduration_ps\x18\x02 \x01(\x04\x12\x10\n\x08begin_ps\x18\x03 \x01(\x04\x12,\n\x0estep_breakdown\x18\x04 \x01(\x0b2\x14.google.protobuf.Any"\xa7\x01\n\rFlowEventInfo\x12\x0f\n\x07flow_id\x18\x01 \x01(\x04\x12\x12\n\nchannel_id\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08category\x18\x04 \x01(\t\x12\x15\n\rstart_time_ps\x18\x05 \x01(\x04\x12\x13\n\x0bend_time_ps\x18\x06 \x01(\x04\x12\x11\n\tbyte_size\x18\x07 \x01(\x04\x12\x12\n\nreplica_id\x18\x08 \x01(\r"E\n\x0cFlowDbResult\x125\n\tflow_info\x18\x01 \x03(\x0b2".tensorflow.profiler.FlowEventInfo"\x7f\n\rAllReduceInfo\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rall_reduce_id\x18\x03 \x01(\x04\x12\x15\n\rstart_time_ps\x18\x04 \x01(\x04\x12\x13\n\x0bend_time_ps\x18\x05 \x01(\x04\x12\x11\n\tbyte_size\x18\x06 \x01(\x04"P\n\x11AllReduceDbResult\x12;\n\x0fall_reduce_info\x18\x01 \x03(\x0b2".tensorflow.profiler.AllReduceInfo"\xea\x06\n\x0fPerCoreStepInfo\x12\x10\n\x08step_num\x18\x01 \x01(\r\x12U\n\x12step_info_per_core\x18\x02 \x03(\x0b29.tensorflow.profiler.PerCoreStepInfo.StepInfoPerCoreEntry\x128\n\x0ehlo_metrics_db\x18\x03 \x01(\x0b2 .tensorflow.profiler.OpMetricsDb\x12Q\n\x10flow_db_per_core\x18\x04 \x03(\x0b27.tensorflow.profiler.PerCoreStepInfo.FlowDbPerCoreEntry\x12a\n\x19core_id_to_replica_id_map\x18\x05 \x03(\x0b2>.tensorflow.profiler.PerCoreStepInfo.CoreIdToReplicaIdMapEntry\x12\\\n\x16all_reduce_db_per_core\x18\x06 \x03(\x0b2<.tensorflow.profiler.PerCoreStepInfo.AllReduceDbPerCoreEntry\x12J\n\x17device_memory_transfers\x18\x07 \x03(\x0b2).tensorflow.profiler.DeviceMemoryTransfer\x1a[\n\x14StepInfoPerCoreEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x122\n\x05value\x18\x02 \x01(\x0b2#.tensorflow.profiler.StepInfoResult:\x028\x01\x1aW\n\x12FlowDbPerCoreEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x120\n\x05value\x18\x02 \x01(\x0b2!.tensorflow.profiler.FlowDbResult:\x028\x01\x1a;\n\x19CoreIdToReplicaIdMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r:\x028\x01\x1aa\n\x17AllReduceDbPerCoreEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x125\n\x05value\x18\x02 \x01(\x0b2&.tensorflow.profiler.AllReduceDbResult:\x028\x01"\xa2\x01\n\x12StepDatabaseResult\x12;\n\rstep_sequence\x18\x01 \x03(\x0b2$.tensorflow.profiler.PerCoreStepInfo\x12\x1b\n\x13use_incomplete_step\x18\x02 \x01(\x08\x12\x19\n\x11num_steps_dropped\x18\x03 \x01(\r\x12\x17\n\x0fempty_intersect\x18\x04 \x01(\x08b\x06proto3', dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_protobuf_dot_op__metrics__pb2.DESCRIPTOR])
_GENERICSTEPBREAKDOWN_TYPEPSENTRY = _descriptor.Descriptor(name='TypePsEntry', full_name='tensorflow.profiler.GenericStepBreakdown.TypePsEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.GenericStepBreakdown.TypePsEntry.key', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.GenericStepBreakdown.TypePsEntry.value', index=1, number=2, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=249, serialized_end=294)
_GENERICSTEPBREAKDOWN = _descriptor.Descriptor(name='GenericStepBreakdown', full_name='tensorflow.profiler.GenericStepBreakdown', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='type_ps', full_name='tensorflow.profiler.GenericStepBreakdown.type_ps', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_GENERICSTEPBREAKDOWN_TYPEPSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=153, serialized_end=294)
_DEVICEMEMORYTRANSFER = _descriptor.Descriptor(name='DeviceMemoryTransfer', full_name='tensorflow.profiler.DeviceMemoryTransfer', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='occurrence', full_name='tensorflow.profiler.DeviceMemoryTransfer.occurrence', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='time_us', full_name='tensorflow.profiler.DeviceMemoryTransfer.time_us', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bytes_transferred', full_name='tensorflow.profiler.DeviceMemoryTransfer.bytes_transferred', index=2, number=3, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=296, serialized_end=382)
_STEPINFORESULT = _descriptor.Descriptor(name='StepInfoResult', full_name='tensorflow.profiler.StepInfoResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_num', full_name='tensorflow.profiler.StepInfoResult.step_num', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_name', full_name='tensorflow.profiler.StepInfoResult.step_name', index=1, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='duration_ps', full_name='tensorflow.profiler.StepInfoResult.duration_ps', index=2, number=2, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='begin_ps', full_name='tensorflow.profiler.StepInfoResult.begin_ps', index=3, number=3, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_breakdown', full_name='tensorflow.profiler.StepInfoResult.step_breakdown', index=4, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=385, serialized_end=523)
_FLOWEVENTINFO = _descriptor.Descriptor(name='FlowEventInfo', full_name='tensorflow.profiler.FlowEventInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='flow_id', full_name='tensorflow.profiler.FlowEventInfo.flow_id', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='channel_id', full_name='tensorflow.profiler.FlowEventInfo.channel_id', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.FlowEventInfo.name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='category', full_name='tensorflow.profiler.FlowEventInfo.category', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='start_time_ps', full_name='tensorflow.profiler.FlowEventInfo.start_time_ps', index=4, number=5, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='end_time_ps', full_name='tensorflow.profiler.FlowEventInfo.end_time_ps', index=5, number=6, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='byte_size', full_name='tensorflow.profiler.FlowEventInfo.byte_size', index=6, number=7, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='replica_id', full_name='tensorflow.profiler.FlowEventInfo.replica_id', index=7, number=8, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=526, serialized_end=693)
_FLOWDBRESULT = _descriptor.Descriptor(name='FlowDbResult', full_name='tensorflow.profiler.FlowDbResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='flow_info', full_name='tensorflow.profiler.FlowDbResult.flow_info', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=695, serialized_end=764)
_ALLREDUCEINFO = _descriptor.Descriptor(name='AllReduceInfo', full_name='tensorflow.profiler.AllReduceInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.profiler.AllReduceInfo.id', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.AllReduceInfo.name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_reduce_id', full_name='tensorflow.profiler.AllReduceInfo.all_reduce_id', index=2, number=3, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='start_time_ps', full_name='tensorflow.profiler.AllReduceInfo.start_time_ps', index=3, number=4, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='end_time_ps', full_name='tensorflow.profiler.AllReduceInfo.end_time_ps', index=4, number=5, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='byte_size', full_name='tensorflow.profiler.AllReduceInfo.byte_size', index=5, number=6, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=766, serialized_end=893)
_ALLREDUCEDBRESULT = _descriptor.Descriptor(name='AllReduceDbResult', full_name='tensorflow.profiler.AllReduceDbResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='all_reduce_info', full_name='tensorflow.profiler.AllReduceDbResult.all_reduce_info', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=895, serialized_end=975)
_PERCORESTEPINFO_STEPINFOPERCOREENTRY = _descriptor.Descriptor(name='StepInfoPerCoreEntry', full_name='tensorflow.profiler.PerCoreStepInfo.StepInfoPerCoreEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.PerCoreStepInfo.StepInfoPerCoreEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.PerCoreStepInfo.StepInfoPerCoreEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1512, serialized_end=1603)
_PERCORESTEPINFO_FLOWDBPERCOREENTRY = _descriptor.Descriptor(name='FlowDbPerCoreEntry', full_name='tensorflow.profiler.PerCoreStepInfo.FlowDbPerCoreEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.PerCoreStepInfo.FlowDbPerCoreEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.PerCoreStepInfo.FlowDbPerCoreEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1605, serialized_end=1692)
_PERCORESTEPINFO_COREIDTOREPLICAIDMAPENTRY = _descriptor.Descriptor(name='CoreIdToReplicaIdMapEntry', full_name='tensorflow.profiler.PerCoreStepInfo.CoreIdToReplicaIdMapEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.PerCoreStepInfo.CoreIdToReplicaIdMapEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.PerCoreStepInfo.CoreIdToReplicaIdMapEntry.value', index=1, number=2, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1694, serialized_end=1753)
_PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY = _descriptor.Descriptor(name='AllReduceDbPerCoreEntry', full_name='tensorflow.profiler.PerCoreStepInfo.AllReduceDbPerCoreEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.PerCoreStepInfo.AllReduceDbPerCoreEntry.key', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.PerCoreStepInfo.AllReduceDbPerCoreEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1755, serialized_end=1852)
_PERCORESTEPINFO = _descriptor.Descriptor(name='PerCoreStepInfo', full_name='tensorflow.profiler.PerCoreStepInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_num', full_name='tensorflow.profiler.PerCoreStepInfo.step_num', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='step_info_per_core', full_name='tensorflow.profiler.PerCoreStepInfo.step_info_per_core', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hlo_metrics_db', full_name='tensorflow.profiler.PerCoreStepInfo.hlo_metrics_db', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='flow_db_per_core', full_name='tensorflow.profiler.PerCoreStepInfo.flow_db_per_core', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_id_to_replica_id_map', full_name='tensorflow.profiler.PerCoreStepInfo.core_id_to_replica_id_map', index=4, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='all_reduce_db_per_core', full_name='tensorflow.profiler.PerCoreStepInfo.all_reduce_db_per_core', index=5, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_memory_transfers', full_name='tensorflow.profiler.PerCoreStepInfo.device_memory_transfers', index=6, number=7, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_PERCORESTEPINFO_STEPINFOPERCOREENTRY, _PERCORESTEPINFO_FLOWDBPERCOREENTRY, _PERCORESTEPINFO_COREIDTOREPLICAIDMAPENTRY, _PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=978, serialized_end=1852)
_STEPDATABASERESULT = _descriptor.Descriptor(name='StepDatabaseResult', full_name='tensorflow.profiler.StepDatabaseResult', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='step_sequence', full_name='tensorflow.profiler.StepDatabaseResult.step_sequence', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='use_incomplete_step', full_name='tensorflow.profiler.StepDatabaseResult.use_incomplete_step', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_steps_dropped', full_name='tensorflow.profiler.StepDatabaseResult.num_steps_dropped', index=2, number=3, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='empty_intersect', full_name='tensorflow.profiler.StepDatabaseResult.empty_intersect', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1855, serialized_end=2017)
_GENERICSTEPBREAKDOWN_TYPEPSENTRY.containing_type = _GENERICSTEPBREAKDOWN
_GENERICSTEPBREAKDOWN.fields_by_name['type_ps'].message_type = _GENERICSTEPBREAKDOWN_TYPEPSENTRY
_STEPINFORESULT.fields_by_name['step_breakdown'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_FLOWDBRESULT.fields_by_name['flow_info'].message_type = _FLOWEVENTINFO
_ALLREDUCEDBRESULT.fields_by_name['all_reduce_info'].message_type = _ALLREDUCEINFO
_PERCORESTEPINFO_STEPINFOPERCOREENTRY.fields_by_name['value'].message_type = _STEPINFORESULT
_PERCORESTEPINFO_STEPINFOPERCOREENTRY.containing_type = _PERCORESTEPINFO
_PERCORESTEPINFO_FLOWDBPERCOREENTRY.fields_by_name['value'].message_type = _FLOWDBRESULT
_PERCORESTEPINFO_FLOWDBPERCOREENTRY.containing_type = _PERCORESTEPINFO
_PERCORESTEPINFO_COREIDTOREPLICAIDMAPENTRY.containing_type = _PERCORESTEPINFO
_PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY.fields_by_name['value'].message_type = _ALLREDUCEDBRESULT
_PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY.containing_type = _PERCORESTEPINFO
_PERCORESTEPINFO.fields_by_name['step_info_per_core'].message_type = _PERCORESTEPINFO_STEPINFOPERCOREENTRY
_PERCORESTEPINFO.fields_by_name['hlo_metrics_db'].message_type = tensorflow_dot_core_dot_profiler_dot_protobuf_dot_op__metrics__pb2._OPMETRICSDB
_PERCORESTEPINFO.fields_by_name['flow_db_per_core'].message_type = _PERCORESTEPINFO_FLOWDBPERCOREENTRY
_PERCORESTEPINFO.fields_by_name['core_id_to_replica_id_map'].message_type = _PERCORESTEPINFO_COREIDTOREPLICAIDMAPENTRY
_PERCORESTEPINFO.fields_by_name['all_reduce_db_per_core'].message_type = _PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY
_PERCORESTEPINFO.fields_by_name['device_memory_transfers'].message_type = _DEVICEMEMORYTRANSFER
_STEPDATABASERESULT.fields_by_name['step_sequence'].message_type = _PERCORESTEPINFO
DESCRIPTOR.message_types_by_name['GenericStepBreakdown'] = _GENERICSTEPBREAKDOWN
DESCRIPTOR.message_types_by_name['DeviceMemoryTransfer'] = _DEVICEMEMORYTRANSFER
DESCRIPTOR.message_types_by_name['StepInfoResult'] = _STEPINFORESULT
DESCRIPTOR.message_types_by_name['FlowEventInfo'] = _FLOWEVENTINFO
DESCRIPTOR.message_types_by_name['FlowDbResult'] = _FLOWDBRESULT
DESCRIPTOR.message_types_by_name['AllReduceInfo'] = _ALLREDUCEINFO
DESCRIPTOR.message_types_by_name['AllReduceDbResult'] = _ALLREDUCEDBRESULT
DESCRIPTOR.message_types_by_name['PerCoreStepInfo'] = _PERCORESTEPINFO
DESCRIPTOR.message_types_by_name['StepDatabaseResult'] = _STEPDATABASERESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
GenericStepBreakdown = _reflection.GeneratedProtocolMessageType('GenericStepBreakdown', (_message.Message,), {'TypePsEntry': _reflection.GeneratedProtocolMessageType('TypePsEntry', (_message.Message,), {'DESCRIPTOR': _GENERICSTEPBREAKDOWN_TYPEPSENTRY, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'}), 'DESCRIPTOR': _GENERICSTEPBREAKDOWN, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(GenericStepBreakdown)
_sym_db.RegisterMessage(GenericStepBreakdown.TypePsEntry)
DeviceMemoryTransfer = _reflection.GeneratedProtocolMessageType('DeviceMemoryTransfer', (_message.Message,), {'DESCRIPTOR': _DEVICEMEMORYTRANSFER, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(DeviceMemoryTransfer)
StepInfoResult = _reflection.GeneratedProtocolMessageType('StepInfoResult', (_message.Message,), {'DESCRIPTOR': _STEPINFORESULT, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(StepInfoResult)
FlowEventInfo = _reflection.GeneratedProtocolMessageType('FlowEventInfo', (_message.Message,), {'DESCRIPTOR': _FLOWEVENTINFO, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(FlowEventInfo)
FlowDbResult = _reflection.GeneratedProtocolMessageType('FlowDbResult', (_message.Message,), {'DESCRIPTOR': _FLOWDBRESULT, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(FlowDbResult)
AllReduceInfo = _reflection.GeneratedProtocolMessageType('AllReduceInfo', (_message.Message,), {'DESCRIPTOR': _ALLREDUCEINFO, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(AllReduceInfo)
AllReduceDbResult = _reflection.GeneratedProtocolMessageType('AllReduceDbResult', (_message.Message,), {'DESCRIPTOR': _ALLREDUCEDBRESULT, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(AllReduceDbResult)
PerCoreStepInfo = _reflection.GeneratedProtocolMessageType('PerCoreStepInfo', (_message.Message,), {'StepInfoPerCoreEntry': _reflection.GeneratedProtocolMessageType('StepInfoPerCoreEntry', (_message.Message,), {'DESCRIPTOR': _PERCORESTEPINFO_STEPINFOPERCOREENTRY, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'}), 'FlowDbPerCoreEntry': _reflection.GeneratedProtocolMessageType('FlowDbPerCoreEntry', (_message.Message,), {'DESCRIPTOR': _PERCORESTEPINFO_FLOWDBPERCOREENTRY, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'}), 'CoreIdToReplicaIdMapEntry': _reflection.GeneratedProtocolMessageType('CoreIdToReplicaIdMapEntry', (_message.Message,), {'DESCRIPTOR': _PERCORESTEPINFO_COREIDTOREPLICAIDMAPENTRY, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'}), 'AllReduceDbPerCoreEntry': _reflection.GeneratedProtocolMessageType('AllReduceDbPerCoreEntry', (_message.Message,), {'DESCRIPTOR': _PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'}), 'DESCRIPTOR': _PERCORESTEPINFO, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(PerCoreStepInfo)
_sym_db.RegisterMessage(PerCoreStepInfo.StepInfoPerCoreEntry)
_sym_db.RegisterMessage(PerCoreStepInfo.FlowDbPerCoreEntry)
_sym_db.RegisterMessage(PerCoreStepInfo.CoreIdToReplicaIdMapEntry)
_sym_db.RegisterMessage(PerCoreStepInfo.AllReduceDbPerCoreEntry)
StepDatabaseResult = _reflection.GeneratedProtocolMessageType('StepDatabaseResult', (_message.Message,), {'DESCRIPTOR': _STEPDATABASERESULT, '__module__': 'tensorflow.core.profiler.protobuf.steps_db_pb2'})
_sym_db.RegisterMessage(StepDatabaseResult)
_GENERICSTEPBREAKDOWN_TYPEPSENTRY._options = None
_PERCORESTEPINFO_STEPINFOPERCOREENTRY._options = None
_PERCORESTEPINFO_FLOWDBPERCOREENTRY._options = None
_PERCORESTEPINFO_COREIDTOREPLICAIDMAPENTRY._options = None
_PERCORESTEPINFO_ALLREDUCEDBPERCOREENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.example import feature_pb2 as tensorflow_dot_core_dot_example_dot_feature__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/util/example_proto_fast_parsing_test.proto', package='tensorflow', syntax='proto3', serialized_options=b'\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n:tensorflow/core/util/example_proto_fast_parsing_test.proto\x12\ntensorflow\x1a%tensorflow/core/example/feature.proto"\xc8\x01\n\x11ExampleWithExtras\x12&\n\x08features\x18\x01 \x01(\x0b2\x14.tensorflow.Features\x12\x0f\n\x06extra1\x18\xb9\n \x01(\t\x12\x0f\n\x06extra2\x18\xba\n \x01(\x03\x12\x0f\n\x06extra3\x18\xbb\n \x01(\x07\x12\x0f\n\x06extra4\x18\xbc\n \x01(\x06\x12\x0f\n\x06extra5\x18\xbd\n \x01(\x01\x12\x0f\n\x06extra6\x18\xbe\n \x03(\x02\x12%\n\x06extra7\x18\xbf\n \x01(\x0b2\x14.tensorflow.FeaturesB\x03\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_example_dot_feature__pb2.DESCRIPTOR])
_EXAMPLEWITHEXTRAS = _descriptor.Descriptor(name='ExampleWithExtras', full_name='tensorflow.ExampleWithExtras', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='features', full_name='tensorflow.ExampleWithExtras.features', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='extra1', full_name='tensorflow.ExampleWithExtras.extra1', index=1, number=1337, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='extra2', full_name='tensorflow.ExampleWithExtras.extra2', index=2, number=1338, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='extra3', full_name='tensorflow.ExampleWithExtras.extra3', index=3, number=1339, type=7, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='extra4', full_name='tensorflow.ExampleWithExtras.extra4', index=4, number=1340, type=6, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='extra5', full_name='tensorflow.ExampleWithExtras.extra5', index=5, number=1341, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='extra6', full_name='tensorflow.ExampleWithExtras.extra6', index=6, number=1342, type=2, cpp_type=6, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='extra7', full_name='tensorflow.ExampleWithExtras.extra7', index=7, number=1343, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=114, serialized_end=314)
_EXAMPLEWITHEXTRAS.fields_by_name['features'].message_type = tensorflow_dot_core_dot_example_dot_feature__pb2._FEATURES
_EXAMPLEWITHEXTRAS.fields_by_name['extra7'].message_type = tensorflow_dot_core_dot_example_dot_feature__pb2._FEATURES
DESCRIPTOR.message_types_by_name['ExampleWithExtras'] = _EXAMPLEWITHEXTRAS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ExampleWithExtras = _reflection.GeneratedProtocolMessageType('ExampleWithExtras', (_message.Message,), {'DESCRIPTOR': _EXAMPLEWITHEXTRAS, '__module__': 'tensorflow.core.util.example_proto_fast_parsing_test_pb2'})
_sym_db.RegisterMessage(ExampleWithExtras)
DESCRIPTOR._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/tools/api/lib/api_objects.proto', package='third_party.tensorflow.tools.api', syntax='proto2', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n*tensorflow/tools/api/lib/api_objects.proto\x12 third_party.tensorflow.tools.api\x1a google/protobuf/descriptor.proto"*\n\x0bTFAPIMember\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05mtype\x18\x02 \x01(\t":\n\x0bTFAPIMethod\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0f\n\x07argspec\x18\x03 \x01(\t"\x92\x01\n\x0bTFAPIModule\x12=\n\x06member\x18\x01 \x03(\x0b2-.third_party.tensorflow.tools.api.TFAPIMember\x12D\n\rmember_method\x18\x02 \x03(\x0b2-.third_party.tensorflow.tools.api.TFAPIMethod"\xa6\x01\n\nTFAPIClass\x12\x13\n\x0bis_instance\x18\x01 \x03(\t\x12=\n\x06member\x18\x02 \x03(\x0b2-.third_party.tensorflow.tools.api.TFAPIMember\x12D\n\rmember_method\x18\x03 \x03(\x0b2-.third_party.tensorflow.tools.api.TFAPIMethod"F\n\nTFAPIProto\x124\n\ndescriptor\x18\x01 \x01(\x0b2 .google.protobuf.DescriptorProto:\x02\x10\x01"\xdd\x01\n\x0bTFAPIObject\x12\x0c\n\x04path\x18\x01 \x01(\t\x12@\n\ttf_module\x18\x02 \x01(\x0b2-.third_party.tensorflow.tools.api.TFAPIModule\x12>\n\x08tf_class\x18\x03 \x01(\x0b2,.third_party.tensorflow.tools.api.TFAPIClass\x12>\n\x08tf_proto\x18\x04 \x01(\x0b2,.third_party.tensorflow.tools.api.TFAPIProto', dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR])
_TFAPIMEMBER = _descriptor.Descriptor(name='TFAPIMember', full_name='third_party.tensorflow.tools.api.TFAPIMember', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='third_party.tensorflow.tools.api.TFAPIMember.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='mtype', full_name='third_party.tensorflow.tools.api.TFAPIMember.mtype', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=114, serialized_end=156)
_TFAPIMETHOD = _descriptor.Descriptor(name='TFAPIMethod', full_name='third_party.tensorflow.tools.api.TFAPIMethod', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='third_party.tensorflow.tools.api.TFAPIMethod.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='path', full_name='third_party.tensorflow.tools.api.TFAPIMethod.path', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='argspec', full_name='third_party.tensorflow.tools.api.TFAPIMethod.argspec', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=158, serialized_end=216)
_TFAPIMODULE = _descriptor.Descriptor(name='TFAPIModule', full_name='third_party.tensorflow.tools.api.TFAPIModule', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='member', full_name='third_party.tensorflow.tools.api.TFAPIModule.member', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='member_method', full_name='third_party.tensorflow.tools.api.TFAPIModule.member_method', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=219, serialized_end=365)
_TFAPICLASS = _descriptor.Descriptor(name='TFAPIClass', full_name='third_party.tensorflow.tools.api.TFAPIClass', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='is_instance', full_name='third_party.tensorflow.tools.api.TFAPIClass.is_instance', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='member', full_name='third_party.tensorflow.tools.api.TFAPIClass.member', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='member_method', full_name='third_party.tensorflow.tools.api.TFAPIClass.member_method', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=368, serialized_end=534)
_TFAPIPROTO = _descriptor.Descriptor(name='TFAPIProto', full_name='third_party.tensorflow.tools.api.TFAPIProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='descriptor', full_name='third_party.tensorflow.tools.api.TFAPIProto.descriptor', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'\x10\x01', is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=536, serialized_end=606)
_TFAPIOBJECT = _descriptor.Descriptor(name='TFAPIObject', full_name='third_party.tensorflow.tools.api.TFAPIObject', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='path', full_name='third_party.tensorflow.tools.api.TFAPIObject.path', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tf_module', full_name='third_party.tensorflow.tools.api.TFAPIObject.tf_module', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tf_class', full_name='third_party.tensorflow.tools.api.TFAPIObject.tf_class', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tf_proto', full_name='third_party.tensorflow.tools.api.TFAPIObject.tf_proto', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=609, serialized_end=830)
_TFAPIMODULE.fields_by_name['member'].message_type = _TFAPIMEMBER
_TFAPIMODULE.fields_by_name['member_method'].message_type = _TFAPIMETHOD
_TFAPICLASS.fields_by_name['member'].message_type = _TFAPIMEMBER
_TFAPICLASS.fields_by_name['member_method'].message_type = _TFAPIMETHOD
_TFAPIPROTO.fields_by_name['descriptor'].message_type = google_dot_protobuf_dot_descriptor__pb2._DESCRIPTORPROTO
_TFAPIOBJECT.fields_by_name['tf_module'].message_type = _TFAPIMODULE
_TFAPIOBJECT.fields_by_name['tf_class'].message_type = _TFAPICLASS
_TFAPIOBJECT.fields_by_name['tf_proto'].message_type = _TFAPIPROTO
DESCRIPTOR.message_types_by_name['TFAPIMember'] = _TFAPIMEMBER
DESCRIPTOR.message_types_by_name['TFAPIMethod'] = _TFAPIMETHOD
DESCRIPTOR.message_types_by_name['TFAPIModule'] = _TFAPIMODULE
DESCRIPTOR.message_types_by_name['TFAPIClass'] = _TFAPICLASS
DESCRIPTOR.message_types_by_name['TFAPIProto'] = _TFAPIPROTO
DESCRIPTOR.message_types_by_name['TFAPIObject'] = _TFAPIOBJECT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TFAPIMember = _reflection.GeneratedProtocolMessageType('TFAPIMember', (_message.Message,), {'DESCRIPTOR': _TFAPIMEMBER, '__module__': 'tensorflow.tools.api.lib.api_objects_pb2'})
_sym_db.RegisterMessage(TFAPIMember)
TFAPIMethod = _reflection.GeneratedProtocolMessageType('TFAPIMethod', (_message.Message,), {'DESCRIPTOR': _TFAPIMETHOD, '__module__': 'tensorflow.tools.api.lib.api_objects_pb2'})
_sym_db.RegisterMessage(TFAPIMethod)
TFAPIModule = _reflection.GeneratedProtocolMessageType('TFAPIModule', (_message.Message,), {'DESCRIPTOR': _TFAPIMODULE, '__module__': 'tensorflow.tools.api.lib.api_objects_pb2'})
_sym_db.RegisterMessage(TFAPIModule)
TFAPIClass = _reflection.GeneratedProtocolMessageType('TFAPIClass', (_message.Message,), {'DESCRIPTOR': _TFAPICLASS, '__module__': 'tensorflow.tools.api.lib.api_objects_pb2'})
_sym_db.RegisterMessage(TFAPIClass)
TFAPIProto = _reflection.GeneratedProtocolMessageType('TFAPIProto', (_message.Message,), {'DESCRIPTOR': _TFAPIPROTO, '__module__': 'tensorflow.tools.api.lib.api_objects_pb2'})
_sym_db.RegisterMessage(TFAPIProto)
TFAPIObject = _reflection.GeneratedProtocolMessageType('TFAPIObject', (_message.Message,), {'DESCRIPTOR': _TFAPIOBJECT, '__module__': 'tensorflow.tools.api.lib.api_objects_pb2'})
_sym_db.RegisterMessage(TFAPIObject)
_TFAPIPROTO._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.compiler.tf2xla import host_compute_metadata_pb2 as tensorflow_dot_compiler_dot_tf2xla_dot_host__compute__metadata__pb2
from ....tensorflow.compiler.xla.service import hlo_pb2 as tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2
from ....tensorflow.compiler.xla import xla_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__pb2
from ....tensorflow.compiler.xla import xla_data_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/xrt/xrt.proto', package='xrt', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n!tensorflow/compiler/xrt/xrt.proto\x12\x03xrt\x1a6tensorflow/compiler/tf2xla/host_compute_metadata.proto\x1a)tensorflow/compiler/xla/service/hlo.proto\x1a!tensorflow/compiler/xla/xla.proto\x1a&tensorflow/compiler/xla/xla_data.proto"\xee\x01\n\x10DeviceAssignment\x12D\n\x13computation_devices\x18\x01 \x03(\x0b2\'.xrt.DeviceAssignment.ComputationDevice\x1a\x93\x01\n\x11ComputationDevice\x12V\n\x0freplica_devices\x18\x01 \x03(\x0b2=.xrt.DeviceAssignment.ComputationDevice.DeviceMeshCoordinates\x1a&\n\x15DeviceMeshCoordinates\x12\r\n\x05value\x18\x01 \x03(\x05"\xaf\x04\n\x14XLAComputationConfig\x12\x14\n\x0cnum_replicas\x18\x01 \x01(\x05\x12\x1d\n\x15num_cores_per_replica\x18\x02 \x01(\x05\x12E\n\x15host_compute_metadata\x18\x03 \x01(\x0b2&.tensorflow.tf2xla.HostComputeMetadata\x12-\n\rprogram_shape\x18\x04 \x01(\x0b2\x16.xla.ProgramShapeProto\x126\n\x16per_core_program_shape\x18\x05 \x03(\x0b2\x16.xla.ProgramShapeProto\x120\n\x11device_assignment\x18\x06 \x01(\x0b2\x15.xrt.DeviceAssignment\x12(\n\rdebug_options\x18\x07 \x01(\x0b2\x11.xla.DebugOptions\x12<\n\x0cexperimental\x18\x08 \x01(\x0b2&.xrt.XLAComputationConfig.Experimental\x1a\x99\x01\n\x0cExperimental\x12V\n\x16stateful_input_indices\x18\x01 \x03(\x0b26.xrt.XLAComputationConfig.Experimental.UpdateIndexPair\x1a1\n\x0fUpdateIndexPair\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0f\n\x07updated\x18\x02 \x01(\x08"c\n\x0eXLAComputation\x12)\n\x06config\x18\x01 \x01(\x0b2\x19.xrt.XLAComputationConfig\x12&\n\x0chlo_snapshot\x18\x02 \x01(\x0b2\x10.xla.HloSnapshot"7\n\rXLAAllocation\x12 \n\x05value\x18\x02 \x01(\x0b2\x11.xla.LiteralProtoJ\x04\x08\x01\x10\x02"d\n\x0cXLATupleNode\x12\x13\n\x0binput_index\x18\x01 \x01(\x05\x12\x1c\n\x14release_input_handle\x18\x02 \x01(\x08\x12!\n\x06tuples\x18\x03 \x03(\x0b2\x11.xrt.XLATupleNode"Z\n\x15CommonExecutionConfig\x12\x12\n\nreplica_id\x18\x01 \x01(\x05\x12\x1d\n\x15local_replica_mapping\x18\x02 \x03(\x05\x12\x0e\n\x06run_id\x18\x03 \x01(\x03"\x98\x02\n\x12XRTExecutionConfig\x12\x16\n\x0edevice_ordinal\x18\x01 \x01(\x05\x12\x1d\n\x15core_index_in_replica\x18\x02 \x01(\x05\x12\x1e\n\x16execution_instance_key\x18\x03 \x01(\t\x12\x10\n\x08rng_seed\x18\x04 \x01(\r\x12\x1d\n\x15release_input_handles\x18\x05 \x01(\x08\x12"\n\x1arelease_compilation_handle\x18\x06 \x01(\x08\x12\x1d\n\x15return_exploded_tuple\x18\x07 \x01(\x08\x121\n\rcommon_config\x18\t \x01(\x0b2\x1a.xrt.CommonExecutionConfigJ\x04\x08\x08\x10\t"\xa3\x01\n\x17XRTChainedExecuteConfig\x12\x10\n\x08rng_seed\x18\x01 \x01(\r\x12\x1d\n\x15core_index_in_replica\x18\x02 \x01(\x05\x12\x1e\n\x16execution_instance_key\x18\x03 \x01(\t\x121\n\rcommon_config\x18\x05 \x01(\x0b2\x1a.xrt.CommonExecutionConfigJ\x04\x08\x04\x10\x05"\x9f\x02\n\x13XRTChainedExecuteOp\x12\x15\n\x0bdata_handle\x18\x01 \x01(\x03H\x00\x12\x1c\n\x12computation_handle\x18\x02 \x01(\x03H\x00\x120\n\x07outputs\x18\x03 \x03(\x0b2\x1f.xrt.XRTChainedExecuteOp.Output\x12.\n\x06inputs\x18\x04 \x03(\x0b2\x1e.xrt.XRTChainedExecuteOp.Input\x1a/\n\x05Input\x12\x10\n\x08op_index\x18\x01 \x01(\x03\x12\x14\n\x0coutput_index\x18\x02 \x01(\x03\x1a4\n\x06Output\x12\x14\n\x0coutput_index\x18\x01 \x01(\x03\x12\x14\n\x0cresult_index\x18\x02 \x01(\x03B\n\n\x08op_oneof">\n\x15XRTChainedExecutePlan\x12%\n\x03ops\x18\x01 \x03(\x0b2\x18.xrt.XRTChainedExecuteOp"*\n\x11XRTMetricsCollect\x12\x15\n\rmetrics_regex\x18\x01 \x03(\t"\x90\x02\n\x0bPercentiles\x12\x14\n\x0cstart_nstime\x18\x01 \x01(\x04\x12\x12\n\nend_nstime\x18\x02 \x01(\x04\x12\x11\n\tmin_value\x18\x03 \x01(\x01\x12\x11\n\tmax_value\x18\x04 \x01(\x01\x12\x0c\n\x04mean\x18\x05 \x01(\x01\x12\x0e\n\x06stddev\x18\x06 \x01(\x01\x12\x13\n\x0bnum_samples\x18\x07 \x01(\x04\x12\x15\n\rtotal_samples\x18\x08 \x01(\x04\x12\x13\n\x0baccumulator\x18\t \x01(\x01\x12&\n\x06points\x18\n \x03(\x0b2\x16.xrt.Percentiles.Point\x1a*\n\x05Point\x12\x12\n\npercentile\x18\x01 \x01(\x01\x12\r\n\x05value\x18\x02 \x01(\x01"\xeb\x01\n\x0cMetricValues\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x11percentiles_value\x18\x02 \x01(\x0b2\x10.xrt.PercentilesH\x00\x12\x15\n\x0bint64_value\x18\x03 \x01(\x03H\x00\x128\n\x0funit_of_measure\x18\x04 \x01(\x0e2\x1f.xrt.MetricValues.UnitOfMeasure"=\n\rUnitOfMeasure\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06NUMBER\x10\x01\x12\x08\n\x04TIME\x10\x02\x12\t\n\x05BYTES\x10\x03B\x0e\n\x0cvalues_oneof"3\n\rMetricsReport\x12"\n\x07metrics\x18\x01 \x03(\x0b2\x11.xrt.MetricValues"/\n\nMemoryInfo\x12\x10\n\x08kb_total\x18\x01 \x01(\x03\x12\x0f\n\x07kb_free\x18\x02 \x01(\x03b\x06proto3', dependencies=[tensorflow_dot_compiler_dot_tf2xla_dot_host__compute__metadata__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_xla__pb2.DESCRIPTOR, tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2.DESCRIPTOR])
_METRICVALUES_UNITOFMEASURE = _descriptor.EnumDescriptor(name='UnitOfMeasure', full_name='xrt.MetricValues.UnitOfMeasure', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='INVALID', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='NUMBER', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='TIME', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='BYTES', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=2652, serialized_end=2713)
_sym_db.RegisterEnumDescriptor(_METRICVALUES_UNITOFMEASURE)
_DEVICEASSIGNMENT_COMPUTATIONDEVICE_DEVICEMESHCOORDINATES = _descriptor.Descriptor(name='DeviceMeshCoordinates', full_name='xrt.DeviceAssignment.ComputationDevice.DeviceMeshCoordinates', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='value', full_name='xrt.DeviceAssignment.ComputationDevice.DeviceMeshCoordinates.value', index=0, number=1, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=417, serialized_end=455)
_DEVICEASSIGNMENT_COMPUTATIONDEVICE = _descriptor.Descriptor(name='ComputationDevice', full_name='xrt.DeviceAssignment.ComputationDevice', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='replica_devices', full_name='xrt.DeviceAssignment.ComputationDevice.replica_devices', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_DEVICEASSIGNMENT_COMPUTATIONDEVICE_DEVICEMESHCOORDINATES], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=308, serialized_end=455)
_DEVICEASSIGNMENT = _descriptor.Descriptor(name='DeviceAssignment', full_name='xrt.DeviceAssignment', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='computation_devices', full_name='xrt.DeviceAssignment.computation_devices', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_DEVICEASSIGNMENT_COMPUTATIONDEVICE], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=217, serialized_end=455)
_XLACOMPUTATIONCONFIG_EXPERIMENTAL_UPDATEINDEXPAIR = _descriptor.Descriptor(name='UpdateIndexPair', full_name='xrt.XLAComputationConfig.Experimental.UpdateIndexPair', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='index', full_name='xrt.XLAComputationConfig.Experimental.UpdateIndexPair.index', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='updated', full_name='xrt.XLAComputationConfig.Experimental.UpdateIndexPair.updated', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=968, serialized_end=1017)
_XLACOMPUTATIONCONFIG_EXPERIMENTAL = _descriptor.Descriptor(name='Experimental', full_name='xrt.XLAComputationConfig.Experimental', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='stateful_input_indices', full_name='xrt.XLAComputationConfig.Experimental.stateful_input_indices', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_XLACOMPUTATIONCONFIG_EXPERIMENTAL_UPDATEINDEXPAIR], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=864, serialized_end=1017)
_XLACOMPUTATIONCONFIG = _descriptor.Descriptor(name='XLAComputationConfig', full_name='xrt.XLAComputationConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='num_replicas', full_name='xrt.XLAComputationConfig.num_replicas', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores_per_replica', full_name='xrt.XLAComputationConfig.num_cores_per_replica', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_compute_metadata', full_name='xrt.XLAComputationConfig.host_compute_metadata', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='program_shape', full_name='xrt.XLAComputationConfig.program_shape', index=3, number=4, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='per_core_program_shape', full_name='xrt.XLAComputationConfig.per_core_program_shape', index=4, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device_assignment', full_name='xrt.XLAComputationConfig.device_assignment', index=5, number=6, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='debug_options', full_name='xrt.XLAComputationConfig.debug_options', index=6, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='experimental', full_name='xrt.XLAComputationConfig.experimental', index=7, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_XLACOMPUTATIONCONFIG_EXPERIMENTAL], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=458, serialized_end=1017)
_XLACOMPUTATION = _descriptor.Descriptor(name='XLAComputation', full_name='xrt.XLAComputation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='config', full_name='xrt.XLAComputation.config', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hlo_snapshot', full_name='xrt.XLAComputation.hlo_snapshot', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1019, serialized_end=1118)
_XLAALLOCATION = _descriptor.Descriptor(name='XLAAllocation', full_name='xrt.XLAAllocation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='value', full_name='xrt.XLAAllocation.value', index=0, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1120, serialized_end=1175)
_XLATUPLENODE = _descriptor.Descriptor(name='XLATupleNode', full_name='xrt.XLATupleNode', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='input_index', full_name='xrt.XLATupleNode.input_index', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='release_input_handle', full_name='xrt.XLATupleNode.release_input_handle', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tuples', full_name='xrt.XLATupleNode.tuples', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1177, serialized_end=1277)
_COMMONEXECUTIONCONFIG = _descriptor.Descriptor(name='CommonExecutionConfig', full_name='xrt.CommonExecutionConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='replica_id', full_name='xrt.CommonExecutionConfig.replica_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='local_replica_mapping', full_name='xrt.CommonExecutionConfig.local_replica_mapping', index=1, number=2, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_id', full_name='xrt.CommonExecutionConfig.run_id', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1279, serialized_end=1369)
_XRTEXECUTIONCONFIG = _descriptor.Descriptor(name='XRTExecutionConfig', full_name='xrt.XRTExecutionConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='device_ordinal', full_name='xrt.XRTExecutionConfig.device_ordinal', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_index_in_replica', full_name='xrt.XRTExecutionConfig.core_index_in_replica', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='execution_instance_key', full_name='xrt.XRTExecutionConfig.execution_instance_key', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='rng_seed', full_name='xrt.XRTExecutionConfig.rng_seed', index=3, number=4, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='release_input_handles', full_name='xrt.XRTExecutionConfig.release_input_handles', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='release_compilation_handle', full_name='xrt.XRTExecutionConfig.release_compilation_handle', index=5, number=6, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='return_exploded_tuple', full_name='xrt.XRTExecutionConfig.return_exploded_tuple', index=6, number=7, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='common_config', full_name='xrt.XRTExecutionConfig.common_config', index=7, number=9, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1372, serialized_end=1652)
_XRTCHAINEDEXECUTECONFIG = _descriptor.Descriptor(name='XRTChainedExecuteConfig', full_name='xrt.XRTChainedExecuteConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='rng_seed', full_name='xrt.XRTChainedExecuteConfig.rng_seed', index=0, number=1, type=13, cpp_type=3, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_index_in_replica', full_name='xrt.XRTChainedExecuteConfig.core_index_in_replica', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='execution_instance_key', full_name='xrt.XRTChainedExecuteConfig.execution_instance_key', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='common_config', full_name='xrt.XRTChainedExecuteConfig.common_config', index=3, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1655, serialized_end=1818)
_XRTCHAINEDEXECUTEOP_INPUT = _descriptor.Descriptor(name='Input', full_name='xrt.XRTChainedExecuteOp.Input', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='op_index', full_name='xrt.XRTChainedExecuteOp.Input.op_index', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_index', full_name='xrt.XRTChainedExecuteOp.Input.output_index', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1995, serialized_end=2042)
_XRTCHAINEDEXECUTEOP_OUTPUT = _descriptor.Descriptor(name='Output', full_name='xrt.XRTChainedExecuteOp.Output', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='output_index', full_name='xrt.XRTChainedExecuteOp.Output.output_index', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='result_index', full_name='xrt.XRTChainedExecuteOp.Output.result_index', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2044, serialized_end=2096)
_XRTCHAINEDEXECUTEOP = _descriptor.Descriptor(name='XRTChainedExecuteOp', full_name='xrt.XRTChainedExecuteOp', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='data_handle', full_name='xrt.XRTChainedExecuteOp.data_handle', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='computation_handle', full_name='xrt.XRTChainedExecuteOp.computation_handle', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='outputs', full_name='xrt.XRTChainedExecuteOp.outputs', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='inputs', full_name='xrt.XRTChainedExecuteOp.inputs', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_XRTCHAINEDEXECUTEOP_INPUT, _XRTCHAINEDEXECUTEOP_OUTPUT], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='op_oneof', full_name='xrt.XRTChainedExecuteOp.op_oneof', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=1821, serialized_end=2108)
_XRTCHAINEDEXECUTEPLAN = _descriptor.Descriptor(name='XRTChainedExecutePlan', full_name='xrt.XRTChainedExecutePlan', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='ops', full_name='xrt.XRTChainedExecutePlan.ops', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2110, serialized_end=2172)
_XRTMETRICSCOLLECT = _descriptor.Descriptor(name='XRTMetricsCollect', full_name='xrt.XRTMetricsCollect', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='metrics_regex', full_name='xrt.XRTMetricsCollect.metrics_regex', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2174, serialized_end=2216)
_PERCENTILES_POINT = _descriptor.Descriptor(name='Point', full_name='xrt.Percentiles.Point', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='percentile', full_name='xrt.Percentiles.Point.percentile', index=0, number=1, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='xrt.Percentiles.Point.value', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2449, serialized_end=2491)
_PERCENTILES = _descriptor.Descriptor(name='Percentiles', full_name='xrt.Percentiles', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='start_nstime', full_name='xrt.Percentiles.start_nstime', index=0, number=1, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='end_nstime', full_name='xrt.Percentiles.end_nstime', index=1, number=2, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='min_value', full_name='xrt.Percentiles.min_value', index=2, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_value', full_name='xrt.Percentiles.max_value', index=3, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='mean', full_name='xrt.Percentiles.mean', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='stddev', full_name='xrt.Percentiles.stddev', index=5, number=6, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_samples', full_name='xrt.Percentiles.num_samples', index=6, number=7, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_samples', full_name='xrt.Percentiles.total_samples', index=7, number=8, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='accumulator', full_name='xrt.Percentiles.accumulator', index=8, number=9, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='points', full_name='xrt.Percentiles.points', index=9, number=10, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_PERCENTILES_POINT], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2219, serialized_end=2491)
_METRICVALUES = _descriptor.Descriptor(name='MetricValues', full_name='xrt.MetricValues', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='xrt.MetricValues.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='percentiles_value', full_name='xrt.MetricValues.percentiles_value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='int64_value', full_name='xrt.MetricValues.int64_value', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='unit_of_measure', full_name='xrt.MetricValues.unit_of_measure', index=3, number=4, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_METRICVALUES_UNITOFMEASURE], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='values_oneof', full_name='xrt.MetricValues.values_oneof', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=2494, serialized_end=2729)
_METRICSREPORT = _descriptor.Descriptor(name='MetricsReport', full_name='xrt.MetricsReport', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='metrics', full_name='xrt.MetricsReport.metrics', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2731, serialized_end=2782)
_MEMORYINFO = _descriptor.Descriptor(name='MemoryInfo', full_name='xrt.MemoryInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='kb_total', full_name='xrt.MemoryInfo.kb_total', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='kb_free', full_name='xrt.MemoryInfo.kb_free', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=2784, serialized_end=2831)
_DEVICEASSIGNMENT_COMPUTATIONDEVICE_DEVICEMESHCOORDINATES.containing_type = _DEVICEASSIGNMENT_COMPUTATIONDEVICE
_DEVICEASSIGNMENT_COMPUTATIONDEVICE.fields_by_name['replica_devices'].message_type = _DEVICEASSIGNMENT_COMPUTATIONDEVICE_DEVICEMESHCOORDINATES
_DEVICEASSIGNMENT_COMPUTATIONDEVICE.containing_type = _DEVICEASSIGNMENT
_DEVICEASSIGNMENT.fields_by_name['computation_devices'].message_type = _DEVICEASSIGNMENT_COMPUTATIONDEVICE
_XLACOMPUTATIONCONFIG_EXPERIMENTAL_UPDATEINDEXPAIR.containing_type = _XLACOMPUTATIONCONFIG_EXPERIMENTAL
_XLACOMPUTATIONCONFIG_EXPERIMENTAL.fields_by_name['stateful_input_indices'].message_type = _XLACOMPUTATIONCONFIG_EXPERIMENTAL_UPDATEINDEXPAIR
_XLACOMPUTATIONCONFIG_EXPERIMENTAL.containing_type = _XLACOMPUTATIONCONFIG
_XLACOMPUTATIONCONFIG.fields_by_name['host_compute_metadata'].message_type = tensorflow_dot_compiler_dot_tf2xla_dot_host__compute__metadata__pb2._HOSTCOMPUTEMETADATA
_XLACOMPUTATIONCONFIG.fields_by_name['program_shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._PROGRAMSHAPEPROTO
_XLACOMPUTATIONCONFIG.fields_by_name['per_core_program_shape'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._PROGRAMSHAPEPROTO
_XLACOMPUTATIONCONFIG.fields_by_name['device_assignment'].message_type = _DEVICEASSIGNMENT
_XLACOMPUTATIONCONFIG.fields_by_name['debug_options'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__pb2._DEBUGOPTIONS
_XLACOMPUTATIONCONFIG.fields_by_name['experimental'].message_type = _XLACOMPUTATIONCONFIG_EXPERIMENTAL
_XLACOMPUTATION.fields_by_name['config'].message_type = _XLACOMPUTATIONCONFIG
_XLACOMPUTATION.fields_by_name['hlo_snapshot'].message_type = tensorflow_dot_compiler_dot_xla_dot_service_dot_hlo__pb2._HLOSNAPSHOT
_XLAALLOCATION.fields_by_name['value'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._LITERALPROTO
_XLATUPLENODE.fields_by_name['tuples'].message_type = _XLATUPLENODE
_XRTEXECUTIONCONFIG.fields_by_name['common_config'].message_type = _COMMONEXECUTIONCONFIG
_XRTCHAINEDEXECUTECONFIG.fields_by_name['common_config'].message_type = _COMMONEXECUTIONCONFIG
_XRTCHAINEDEXECUTEOP_INPUT.containing_type = _XRTCHAINEDEXECUTEOP
_XRTCHAINEDEXECUTEOP_OUTPUT.containing_type = _XRTCHAINEDEXECUTEOP
_XRTCHAINEDEXECUTEOP.fields_by_name['outputs'].message_type = _XRTCHAINEDEXECUTEOP_OUTPUT
_XRTCHAINEDEXECUTEOP.fields_by_name['inputs'].message_type = _XRTCHAINEDEXECUTEOP_INPUT
_XRTCHAINEDEXECUTEOP.oneofs_by_name['op_oneof'].fields.append(_XRTCHAINEDEXECUTEOP.fields_by_name['data_handle'])
_XRTCHAINEDEXECUTEOP.fields_by_name['data_handle'].containing_oneof = _XRTCHAINEDEXECUTEOP.oneofs_by_name['op_oneof']
_XRTCHAINEDEXECUTEOP.oneofs_by_name['op_oneof'].fields.append(_XRTCHAINEDEXECUTEOP.fields_by_name['computation_handle'])
_XRTCHAINEDEXECUTEOP.fields_by_name['computation_handle'].containing_oneof = _XRTCHAINEDEXECUTEOP.oneofs_by_name['op_oneof']
_XRTCHAINEDEXECUTEPLAN.fields_by_name['ops'].message_type = _XRTCHAINEDEXECUTEOP
_PERCENTILES_POINT.containing_type = _PERCENTILES
_PERCENTILES.fields_by_name['points'].message_type = _PERCENTILES_POINT
_METRICVALUES.fields_by_name['percentiles_value'].message_type = _PERCENTILES
_METRICVALUES.fields_by_name['unit_of_measure'].enum_type = _METRICVALUES_UNITOFMEASURE
_METRICVALUES_UNITOFMEASURE.containing_type = _METRICVALUES
_METRICVALUES.oneofs_by_name['values_oneof'].fields.append(_METRICVALUES.fields_by_name['percentiles_value'])
_METRICVALUES.fields_by_name['percentiles_value'].containing_oneof = _METRICVALUES.oneofs_by_name['values_oneof']
_METRICVALUES.oneofs_by_name['values_oneof'].fields.append(_METRICVALUES.fields_by_name['int64_value'])
_METRICVALUES.fields_by_name['int64_value'].containing_oneof = _METRICVALUES.oneofs_by_name['values_oneof']
_METRICSREPORT.fields_by_name['metrics'].message_type = _METRICVALUES
DESCRIPTOR.message_types_by_name['DeviceAssignment'] = _DEVICEASSIGNMENT
DESCRIPTOR.message_types_by_name['XLAComputationConfig'] = _XLACOMPUTATIONCONFIG
DESCRIPTOR.message_types_by_name['XLAComputation'] = _XLACOMPUTATION
DESCRIPTOR.message_types_by_name['XLAAllocation'] = _XLAALLOCATION
DESCRIPTOR.message_types_by_name['XLATupleNode'] = _XLATUPLENODE
DESCRIPTOR.message_types_by_name['CommonExecutionConfig'] = _COMMONEXECUTIONCONFIG
DESCRIPTOR.message_types_by_name['XRTExecutionConfig'] = _XRTEXECUTIONCONFIG
DESCRIPTOR.message_types_by_name['XRTChainedExecuteConfig'] = _XRTCHAINEDEXECUTECONFIG
DESCRIPTOR.message_types_by_name['XRTChainedExecuteOp'] = _XRTCHAINEDEXECUTEOP
DESCRIPTOR.message_types_by_name['XRTChainedExecutePlan'] = _XRTCHAINEDEXECUTEPLAN
DESCRIPTOR.message_types_by_name['XRTMetricsCollect'] = _XRTMETRICSCOLLECT
DESCRIPTOR.message_types_by_name['Percentiles'] = _PERCENTILES
DESCRIPTOR.message_types_by_name['MetricValues'] = _METRICVALUES
DESCRIPTOR.message_types_by_name['MetricsReport'] = _METRICSREPORT
DESCRIPTOR.message_types_by_name['MemoryInfo'] = _MEMORYINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
DeviceAssignment = _reflection.GeneratedProtocolMessageType('DeviceAssignment', (_message.Message,), {'ComputationDevice': _reflection.GeneratedProtocolMessageType('ComputationDevice', (_message.Message,), {'DeviceMeshCoordinates': _reflection.GeneratedProtocolMessageType('DeviceMeshCoordinates', (_message.Message,), {'DESCRIPTOR': _DEVICEASSIGNMENT_COMPUTATIONDEVICE_DEVICEMESHCOORDINATES, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'DESCRIPTOR': _DEVICEASSIGNMENT_COMPUTATIONDEVICE, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'DESCRIPTOR': _DEVICEASSIGNMENT, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(DeviceAssignment)
_sym_db.RegisterMessage(DeviceAssignment.ComputationDevice)
_sym_db.RegisterMessage(DeviceAssignment.ComputationDevice.DeviceMeshCoordinates)
XLAComputationConfig = _reflection.GeneratedProtocolMessageType('XLAComputationConfig', (_message.Message,), {'Experimental': _reflection.GeneratedProtocolMessageType('Experimental', (_message.Message,), {'UpdateIndexPair': _reflection.GeneratedProtocolMessageType('UpdateIndexPair', (_message.Message,), {'DESCRIPTOR': _XLACOMPUTATIONCONFIG_EXPERIMENTAL_UPDATEINDEXPAIR, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'DESCRIPTOR': _XLACOMPUTATIONCONFIG_EXPERIMENTAL, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'DESCRIPTOR': _XLACOMPUTATIONCONFIG, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XLAComputationConfig)
_sym_db.RegisterMessage(XLAComputationConfig.Experimental)
_sym_db.RegisterMessage(XLAComputationConfig.Experimental.UpdateIndexPair)
XLAComputation = _reflection.GeneratedProtocolMessageType('XLAComputation', (_message.Message,), {'DESCRIPTOR': _XLACOMPUTATION, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XLAComputation)
XLAAllocation = _reflection.GeneratedProtocolMessageType('XLAAllocation', (_message.Message,), {'DESCRIPTOR': _XLAALLOCATION, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XLAAllocation)
XLATupleNode = _reflection.GeneratedProtocolMessageType('XLATupleNode', (_message.Message,), {'DESCRIPTOR': _XLATUPLENODE, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XLATupleNode)
CommonExecutionConfig = _reflection.GeneratedProtocolMessageType('CommonExecutionConfig', (_message.Message,), {'DESCRIPTOR': _COMMONEXECUTIONCONFIG, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(CommonExecutionConfig)
XRTExecutionConfig = _reflection.GeneratedProtocolMessageType('XRTExecutionConfig', (_message.Message,), {'DESCRIPTOR': _XRTEXECUTIONCONFIG, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XRTExecutionConfig)
XRTChainedExecuteConfig = _reflection.GeneratedProtocolMessageType('XRTChainedExecuteConfig', (_message.Message,), {'DESCRIPTOR': _XRTCHAINEDEXECUTECONFIG, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XRTChainedExecuteConfig)
XRTChainedExecuteOp = _reflection.GeneratedProtocolMessageType('XRTChainedExecuteOp', (_message.Message,), {'Input': _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), {'DESCRIPTOR': _XRTCHAINEDEXECUTEOP_INPUT, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'Output': _reflection.GeneratedProtocolMessageType('Output', (_message.Message,), {'DESCRIPTOR': _XRTCHAINEDEXECUTEOP_OUTPUT, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'DESCRIPTOR': _XRTCHAINEDEXECUTEOP, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XRTChainedExecuteOp)
_sym_db.RegisterMessage(XRTChainedExecuteOp.Input)
_sym_db.RegisterMessage(XRTChainedExecuteOp.Output)
XRTChainedExecutePlan = _reflection.GeneratedProtocolMessageType('XRTChainedExecutePlan', (_message.Message,), {'DESCRIPTOR': _XRTCHAINEDEXECUTEPLAN, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XRTChainedExecutePlan)
XRTMetricsCollect = _reflection.GeneratedProtocolMessageType('XRTMetricsCollect', (_message.Message,), {'DESCRIPTOR': _XRTMETRICSCOLLECT, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(XRTMetricsCollect)
Percentiles = _reflection.GeneratedProtocolMessageType('Percentiles', (_message.Message,), {'Point': _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {'DESCRIPTOR': _PERCENTILES_POINT, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'}), 'DESCRIPTOR': _PERCENTILES, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(Percentiles)
_sym_db.RegisterMessage(Percentiles.Point)
MetricValues = _reflection.GeneratedProtocolMessageType('MetricValues', (_message.Message,), {'DESCRIPTOR': _METRICVALUES, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(MetricValues)
MetricsReport = _reflection.GeneratedProtocolMessageType('MetricsReport', (_message.Message,), {'DESCRIPTOR': _METRICSREPORT, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(MetricsReport)
MemoryInfo = _reflection.GeneratedProtocolMessageType('MemoryInfo', (_message.Message,), {'DESCRIPTOR': _MEMORYINFO, '__module__': 'tensorflow.compiler.xrt.xrt_pb2'})
_sym_db.RegisterMessage(MemoryInfo)
